## Kickstart Configurator - A graphical kickstart file generator
## Copyright (C) 2000, 2001, 2002, 2003 Red Hat, Inc.
## Copyright (C) 2000, 2001, 2002, 2003 Brent Fox <bfox@redhat.com>
##                                      Tammy Fox <tfox@redhat.com>

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#Kickstart Configurator Package Selection

import gtk
import gtk.glade
import gobject
import string
import getopt
import os

##
## I18N
## 
from rhpl.translate import _, N_
import rhpl.translate as translate
domain = 'system-config-kickstart'
translate.textdomain (domain)
gtk.glade.bindtextdomain(domain)

class Packages:

    def __init__(self, xml, kickstartData):
        self.kickstartData = kickstartData
        self.package_vbox = xml.get_widget("package_vbox")
        self.package_label_box = xml.get_widget("package_label_box")
        self.resolve_deps_radio = xml.get_widget("resolve_deps_radio")
        self.ignore_deps_radio = xml.get_widget("ignore_deps_radio")


        self.packages_eventbox = xml.get_widget("packages_eventbox")
        self.packages_eventbox.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse("#4a59a6"))
        self.packages_label = xml.get_widget("packages_label")
        self.packages_label.set_markup("<span foreground='white'><big><b>%s</b></big></span>" % (self.packages_label.get(),))

        self.packages_view = xml.get_widget("packages_view")
        self.packages_view.get_selection().set_mode(gtk.SELECTION_NONE)

        self.packages_store = gtk.ListStore(gobject.TYPE_BOOLEAN, gobject.TYPE_STRING)
        self.packages_view.set_model(self.packages_store)

        self.create_columns(self.packages_view, self.packages_store)

        packagesList = ["base",
                        "base-x",
                        "core",
                        "database-tools",
                        "development",
                        "gnome-desktop",
                        "kde-desktop",
                        "legacy-software-development",
                        "miscallvars",
                        "others",
                        "printing",
                        "selected-by-dependency",
                        "server",
                        "system-tools",
                        "web-browsers",
                        "Chinese-support",
                        "Japanese-support",
                        "Korean-support",
                        "everything"
                        ]


        for pkg in packagesList:
            iter = self.packages_store.append()
            self.packages_store.set_value(iter, 1, pkg)

    def create_columns(self, view, store):
        self.checkbox = gtk.CellRendererToggle()
        col = gtk.TreeViewColumn('', self.checkbox, active = 0)
        col.set_fixed_width(20)
        col.set_clickable(gtk.TRUE)
        self.checkbox.connect("toggled", self.packageToggled, store)
        view.append_column(col)

        col = gtk.TreeViewColumn("", gtk.CellRendererText(), text=1)
        view.append_column(col)

    def packageToggled(self, data, row, store):
        iter = store.get_iter((int(row),))
        val = store.get_value(iter, 0)
        store.set_value(iter, 0 , not val)

    def getData(self):
        packageList = []

        if self.resolve_deps_radio.get_active() == 1:
             self.kickstartData.setPackage(["--resolvedeps"])
        elif self.ignore_deps_radio.get_active() == 1:
             self.kickstartData.setPackage(["--ignoredeps"])

	packageList = self.getPkgData(self.packages_store, packageList)

        self.kickstartData.setPackageGroupList(packageList)

    def getPkgData(self, store, packageList):
        iter = store.get_iter_first()
        
        #Loop over the package list and see what was selected
        while iter:
            if store.get_value(iter, 0) == gtk.TRUE:
                packageList.append(store.get_value(iter, 1))
            iter = store.iter_next(iter)

        return packageList

    def lookupPackageInList(self, package, store):
        iter = store.get_iter_first()
        while iter:
            if package == store.get_value(iter, 1):
                store.set_value(iter, 0, gtk.TRUE)
            iter = store.iter_next(iter)

    def setSensitive(self, boolean):
        if boolean == gtk.FALSE:
            self.package_vbox.hide()
            self.package_label_box.show()
        else:
            self.package_vbox.show()
            self.package_label_box.hide()

    def fillData(self):
        if self.kickstartData.getPackage():
            opts, args = getopt.getopt(self.kickstartData.getPackage(), "d:h", ["resolvedeps", "ignoredeps"])

            for opt, value in opts:
                if opt == "--resolvedeps":
                    self.resolve_deps_radio.set_active(gtk.TRUE)
                elif opt == "--ignoredeps":
                    self.ignore_deps_radio.set_active(gtk.TRUE)

        packageList = self.kickstartData.getPackageGroupList()

        for package in packageList:
            package = string.replace(package, "@", "")
            package = string.strip(package)
            self.lookupPackageInList(package, self.packages_store)
